function [ U ] = paperV1_mtxGen_Alg4( m, n, ~, mu )
%MTXGEN_LI Returns a m by n matrix U with orthonormal columns and leverage
%scores li.
%
%   [ U ] = mtxGen_li( m, n, li ) Returns a m by n matrix U with
%     orthonormal columns and leverage scores li.
%
%   [ U ] = mtxGen_li( 'info' ) will return data about this matrix generation
%     algorithm, including what what inputs it needs.


if nargin==1
    if strcmp(m,'info');
        U=struct;
        U.plotName='Old Alg 4';
        U.name='Old Matrix with specified coherence (Old Alg 4)';
        U.inputsNeeded.m=1;
        U.inputsNeeded.n=1;
        U.inputsNeeded.c=0;
        U.inputsNeeded.mu=1;
        U.inputsNeeded.delta=0;
        U.inputsNeeded.li=0;
        U.inputsNeeded.Q=0;
        U.type='mtxGen';
        return;
    else
        
        error('Wrong number of inputs.')
        
    end
elseif nargin~=4
    
    error('Wrong number of inputs.')
end

if m<n
    error('We must have m>=n')
end

if mu<n/m || mu>1
    error('n/m <= mu <= 1')
end


U = mtxGenMethod2( m,n,mu );


end


function [ U] = mtxGenMethod2( m,n,mu )
%MTXGENMETHOD1 Generates a mXn matrix of coherence coh
%aus and zus are unsorted, a and z are sorted
%here we recreate the method

U=zeros(m,n);U(1:n,1:n)=eye(n);
zus=ones(m,1)*(n-mu)/(m-1);zus(end)=mu;
aus=zeros(m,1);aus(1:n)=1;
    [z,~]=sort(zus,'ascend');
for ii=1:m-1

[a,aIndex]=sort(aus,'ascend');

amz=a-z;
amz2=(a(1:end-1)-z(2:end));
% amz2=amz;
% [a z sign(a-z)]
% [a(1:end-1) z(2:end)]
k1=find(abs(amz)<10^-15,1,'first');
k2=find(abs(amz)<10^-15,1,'last');
if isempty(k1)
    k1=0;k2=m;
end

j= find((amz(max(k1+1,1):end))>10^-15,1,'first')+k1;
i= find((amz2(1:(k2-1)))<-10^-15,1,'last');
if isempty(j) || isempty(i)
    break;%sometimes we finish early
end
% i= find((a-z)<0,1,'last')
[c,s] = DiffcsSol(U,aIndex(i),aIndex(j),z(i));
% U([aIndex(i) aIndex(j)],:)
U([aIndex(i) aIndex(j)],:) = [c s;-s c]*U([aIndex(i) aIndex(j)],:);
% U([aIndex(i) aIndex(j)],:)
aus(aIndex(i)) = U(aIndex(i),:)*U(aIndex(i),:)';
aus(aIndex(j)) = U(aIndex(j),:)*U(aIndex(j),:)';

end

end
function [c,s]=DiffcsSol(A,i,j,nom)%I previously verified that this is solvable
%here I use the method from dhillon and tropp to solve
a=A(i,:)';
aa=a'*a;
b=A(j,:)';
bb=b'*b;ab=a'*b;
tmp1=-ab/(bb-nom);
tmp2=(sqrt(ab^2-(aa-nom)*(bb-nom)))/(bb-nom);%we define these variables to avoid sign cancellations.
if tmp1<=0
    tp=tmp1 - tmp2;
else
    tp=tmp1+tmp2;
end
% tp=-(ab + sqrt(ab^2-(aa-nom)*(bb-nom)))/(bb-nom);
c=1/sqrt(1+tp^2);
s=c*tp;
end