function [ bound ] = paperV1_theoBound1(m, ~, c, mu, delta, ~ ,~)
%PAPERV1_THEOBOUND1 Returns a bound for the condition number of SQ.  The bound
%name can be found by running paperV1_theoBound1( 'info' ).
%
%   b = paperV1_theoBound1( m, n, c, mu, delta, li, Q ) returns this bound for
%     the condition number of SQ given the inputs.
%     Inputs:
%        m: Number of rows in Q
%        n: Number of columns in Q
%        c: Number of rows to sample
%        mu: Coherence of Q
%        delta: Failure rate
%        li: Leverage scores of Q
%        Q: The matrix we are testing
%
%   b = paperV1_theoBound1( 'info' ) will return data about this sampling
%     algorithm, including what what inputs it needs.

if nargin==1
    if strcmp(m,'info');
        bound=struct;
        bound.plotName='Old 3.2';
        bound.name='Old Theorem 3.2';
        bound.inputsNeeded.m=1;
        bound.inputsNeeded.n=1;
        bound.inputsNeeded.c=1;
        bound.inputsNeeded.mu=1;
        bound.inputsNeeded.delta=1;
        bound.inputsNeeded.li=0;
        bound.inputsNeeded.Q=0;
        bound.type='Bound';
        return;
    else
        error('Wrong number of inputs.')
    end
elseif nargin~=7
    error('Wrong number of inputs.')
end
if delta<=0 || delta>=1
    error('invalid delta')
end
cc=96*m*mu;
if cc*log(cc/sqrt(delta)) > c
    bound = 'badEps';
else
    epsilon = ((m*mu*96)/delta^(1/2))^(1/2)/exp(lambertw(0, c/delta^(1/2))/2);
    if epsilon<=0 || epsilon>=1
        bound = 'badEps';
    else
        bound=sqrt((1+epsilon)/(1-epsilon));
    end
end
end
