function [ bound ] = paperV2_Bound_LeverageScores_use_all_li( m, n, c, mu, delta, li, Q )
%BOUND_LEVERAGESCORES_USE_ALL_LI Returns a bound for the condition number of SQ.  The bound
%name can be found by running Bound_LeverageScores_use_all_li( 'info' ).
%
%   b = Bound_LeverageScores_use_all_li( m, n, c, mu, delta, li, Q ) returns this bound for
%     the condition number of SQ given the inputs.
%     Inputs:
%        m: Number of rows in Q
%        n: Number of columns in Q
%        c: Number of rows to sample
%        mu: Coherence of Q
%        delta: Failure rate
%        li: Leverage scores of Q
%        Q: The matrix we are testing
%
%   b = Bound_LeverageScores_use_all_li( 'info' ) will return data about this sampling
%     algorithm, including what what inputs it needs.

if nargin==1
    if strcmp(m,'info');
        bound=struct;
        bound.plotName='5.2';
        bound.name='Theorem 5.2';
        bound.inputsNeeded.m=1;
        bound.inputsNeeded.n=1;
        bound.inputsNeeded.c=1;
        bound.inputsNeeded.mu=1;
        bound.inputsNeeded.delta=1;
        bound.inputsNeeded.li=1;
        bound.inputsNeeded.Q=1;
        bound.type='Bound';
        return;
    else
        error('Wrong number of inputs.')
    end
elseif nargin~=7
    error('Wrong number of inputs.')
end
%must inpput how we want leverage scores distributedvbutton =
persistent normLQs
if isempty(normLQs)
    %     info=Bound_LeverageScores_use_all_li('info');
    %         warndlg(['Warning: ' info.name ' uses a persistent variable. ||Q^TLQ|| is only computed once. Do not run this bound for experiments with multiple m, n, mu, li, or A!'])
    
    for i=1:m
        Q(i,:)=Q(i,:)*sqrt(li(i));%square root because norLQs=norm(Q^tLQ)
    end
    normLQs=norm(Q)^2;
end
%all of the work above was used to generate normLQs
ell=2/3*log(2*n/delta);
ccc=-3*ell*m*normLQs;
bbb=-mu*ell*m;
aaa=c;
epsilon=(-bbb+sqrt(bbb^2-4*aaa*ccc))/(2*aaa);
if epsilon<1 && epsilon>=0
    bound=sqrt((1+epsilon)/(1-epsilon));
else
    bound='badEps';
end

end