function [ Q ] = paperV2_Sample_exactlyC( Q, c )
%SAMPLE_EXACTLYC Returns the sampled matrix SQ.
%
%   SQ = Sample_exactlyC( Q, c ) returns the sampled matrix SQ where S is
%     defined via the Exactly(c) sampling algorithm.  c is the number of
%     sampled rows.
%
%   SQ = Sample_exactlyC( 'info' ) will return data about this sampling
%     algorithm, including what what inputs it needs.

if nargin==1
    if strcmp(Q,'info');
        Q=struct;
        Q.plotName='Alg 3.2';
        Q.name='Exactly(c) Uniform sampling with replacement (Alg 3.2, old_Alg 2)';
        Q.inputsNeeded.m=0;
        Q.inputsNeeded.n=0;
        Q.inputsNeeded.c=1;
        Q.inputsNeeded.mu=0;
        Q.inputsNeeded.delta=0;
        Q.inputsNeeded.li=0;
        Q.inputsNeeded.Q=1;
        Q.type='Sample';
        return;
    else
        error('Wrong number of inputs.')
    end
elseif nargin~=2
    error('Wrong number of inputs.')
end
m=size(Q,1);
choice=zeros(1,c);
for i=1:c;
    pick=floor(m*rand)+1;
    choice(i)=pick;
end
Q=(1/sqrt(c/m))*Q(choice,:);
end
