function [ li ] = paperV2_liDist_manyBig( m,n,mu )
%PAPERV2_LIDIST_MANYBIG Returns a leverage score distribution with many large leverage
%scores for a m by n matrix with coherence mu.
%
%   li = paperV2_liDist_manyBig( m, n, mu ) Returns a leverage score distribution with
%     many large leverage scores for a m by n matrix with coherence mu.
%
%   li = paperV2_liDist_manyBig( 'info' ) will return data about this leverage score
%     distribution function, including what what inputs it needs.

if nargin==1
    if strcmp(m,'info');
        li=struct;
        li.plotName='Alg 6.3';
        li.name='Many zero leverage scores (Alg 6.3)';
        li.inputsNeeded.m=1;
        li.inputsNeeded.n=1;
        li.inputsNeeded.c=0;
        li.inputsNeeded.mu=1;
        li.inputsNeeded.delta=0;
        li.inputsNeeded.li=0;
        li.inputsNeeded.Q=0;
        li.type='liDist';
        return;
    else
        error('Wrong number of inputs.')
    end
elseif nargin~=3
    error('Wrong number of inputs.')
end
    if mu<n/m || mu>1
        error('mu must satisfy n/m<=mu<=1')
    end
    
    nbig=floor(n/mu);%number of big leverage scores
    
    if nbig<m
        li = [mu*ones(nbig,1); n-nbig*mu; zeros(m-nbig-1,1)];
    elseif nbig==m
        li = mu*ones(nbig,1);
    end
end



