function [ li, Q ] = leverageScores( Q )
%LEVERAGESCORES Calculate the coherence of a given matrix Q.
%
%   li = coherence(Q) returns the leverage sores of the matrix Q. If Q does
%   not have orthonormal columns, then we use matlab's qr function to
%   calculate a basis of orthonormal columns for Q.
%
%   [mu,Q] = coherence(Q) also returns a basis of orthonormal columns for
%   the input matrix Q.

[m,n] = size(Q);

if n > m
    error('Leverage scores are only defined for m x n matrices where n<=m.')
end

%Ensure that Q has orthonormal columns.

if max(max(abs(Q'*Q - eye(n)))) > eps*m
    [Q,~]=qr(Q,0);
end

%Calculate leverage scores, this method is more memory efficient than
%li=sum(Q.^2,2);
li=zeros(m,1);
for i=1:m
    li(i)=sum(Q(i,:).^2);
end
end

